<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>About</name>
    <message>
        <location filename="../components/About.qml" line="9"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="80"/>
        <source>&lt;p&gt;This service is paid for entirely by donations from users like you. &lt;a href=&quot;%1&quot;&gt;Please donate&lt;/a&gt;.&lt;/p&gt;</source>
        <extracomment>donation text of the about dialog</extracomment>
        <translation>&lt;p&gt;Bu hizmetin bedeli, sizin gibi kullanıcıların bağışlarıyla sağlanıyor. &lt;a href=&quot;%1&quot;&gt;Lütfen bağış yapın&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="103"/>
        <source>%1 version: 
%2</source>
        <extracomment>screenshot https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/screenshots/about.png %1 -&gt; application name %2 -&gt; version string</extracomment>
        <translation>%1 sürüm: 
%2</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../components/Footer.qml" line="180"/>
        <source>Recommended</source>
        <translation>Önerilen</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../components/Help.qml" line="7"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="20"/>
        <source>Troubleshooting and support</source>
        <translation>Sorun giderme ve destek</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="31"/>
        <source>Report a bug</source>
        <translation>Bir hata bildirin</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="42"/>
        <source>How to uninstall</source>
        <translation>Nasıl kaldırılır</translation>
    </message>
</context>
<context>
    <name>InitErrors</name>
    <message>
        <location filename="../components/InitErrors.qml" line="31"/>
        <source>Could not find helpers. Please check your installation</source>
        <translation>Yardımcılar bulunamadı. Lütfen kurulumunuzu denetleyin.</translation>
    </message>
    <message>
        <location filename="../components/InitErrors.qml" line="44"/>
        <source>Could not find polkit agent.</source>
        <translation>polkit uygulaması bulunamadı.</translation>
    </message>
</context>
<context>
    <name>Locations</name>
    <message>
        <location filename="../components/Locations.qml" line="21"/>
        <source>Select Location</source>
        <translation>Konum seçin</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="27"/>
        <source>Automatically use best connection</source>
        <extracomment>this is in the radio button for the auto selection</extracomment>
        <translation>Otomatik olarak en iyi bağlantı kullanılsın</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="29"/>
        <source>Manually select</source>
        <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
        <translation>El ile seçim</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="31"/>
        <source>Switching gateway…</source>
        <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
        <translation>Ağ geçidi değiştiriliyor…</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="33"/>
        <source>Only locations with bridges</source>
        <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
        <translation>Yalnızca köprü ile ulaşılan konumlar</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="65"/>
        <source>Recommended</source>
        <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
        <translation>Önerilen</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../components/MainView.qml" line="43"/>
        <location filename="../components/MainView.qml" line="66"/>
        <source>Donate</source>
        <translation>Bağış yapın</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="59"/>
        <source>Preferences</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="73"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="80"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="87"/>
        <source>Quit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="111"/>
        <source>Please donate!</source>
        <translation>Lütfen bağış yapın!</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="125"/>
        <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
        <translation>Bu hizmet tamamen sizin gibi kullanıcıların bağışları sayesinde sunulabiliyor. Bir VPN ağını işletme maliyeti, kişi başına aylık 5 Amerikan doları civarındadır. Ancak her katkı değerlidir. Siz de bağış yapmak ister misiniz?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../components/Preferences.qml" line="11"/>
        <source>Preferences</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="55"/>
        <source>Turn off the VPN to make changes</source>
        <translation>Değişiklik yapmak için VPN bağlantısını kapatın</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="71"/>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="105"/>
        <source>Censorship circumvention</source>
        <translation>Engellemeyi aşma</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="113"/>
        <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
        <translation>Bu yöntemler engellemeyi aşabilir, ancak yavaştır. Yalnızca gerek duyduğunuz zaman kullanın.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="127"/>
        <source>Use obfs4 bridges</source>
        <translation>obfs4 köprüleri kullanılsın</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="153"/>
        <source>Traffic is obfuscated to bypass blocks</source>
        <translation>Engelleri aşmak için trafik gizlenir</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="167"/>
        <source>Use Snowflake</source>
        <translation>Snowflake kullanılsın</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="182"/>
        <source>Snowflake needs Tor installed in your system</source>
        <translation>Snowflake için sisteminizde Tor kurulu olması gerekir</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="195"/>
        <source>Transport</source>
        <translation>Taşıyıcı</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="203"/>
        <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
        <translation>UDP, VPN bağlantısını daha hızlı yapabilir. Bazı ağlarda engellenmiş olabilir.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="216"/>
        <source>Use UDP if available</source>
        <translation>Olabiliyorsa UDP kullanılsın</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="231"/>
        <source>KCP might work when UDP is blocked on some networks.</source>
        <translation>Bazı ağlarda UDP engellenmişse KCP çalışabilir.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="244"/>
        <source>Use KCP if available</source>
        <translation>Mevcut ise KCP kullan</translation>
    </message>
</context>
<context>
    <name>Splash</name>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>There is a newer version available. </source>
        <translation>Yeni bir sürüm yayınlanmış.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
        <translation>Yeni kurulumu başlatmadan önce lütfen önceki kurulumu &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;kaldırdığınızdan&lt;/a&gt; emin olun.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="105"/>
        <source>UPGRADE NOW</source>
        <translation>ŞİMDİ YÜKSELT</translation>
    </message>
</context>
<context>
    <name>StatusBox</name>
    <message>
        <location filename="../components/StatusBox.qml" line="78"/>
        <source>This can take several minutes</source>
        <translation>Bu işlem birkaç dakika sürebilir</translation>
    </message>
</context>
<context>
    <name>Systray</name>
    <message>
        <location filename="../components/Systray.qml" line="16"/>
        <source>Checking status…</source>
        <translation>Durum denetleniyor…</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="36"/>
        <source>Donate</source>
        <translation>Bağış yapın</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Hide</source>
        <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
        <translation>Gizle</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Show</source>
        <translation>Görüntüle</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="57"/>
        <source>Quit</source>
        <extracomment>Part of the systray menu; quits the application</extracomment>
        <translation>Çıkış</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="74"/>
        <source>Connect to</source>
        <translation>Şuraya bağlan</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="76"/>
        <source>Connect</source>
        <translation>Bağlantı kur</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="79"/>
        <source>Disconnect</source>
        <translation>Bağlantıyı kes</translation>
    </message>
</context>
<context>
    <name>VPNState</name>
    <message>
        <location filename="../components/VPNState.qml" line="26"/>
        <source>Setting up</source>
        <translation>Kuruluyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="51"/>
        <location filename="../components/VPNState.qml" line="153"/>
        <source>Connecting</source>
        <translation>Bağlantı kuruluyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="82"/>
        <source>Unsecured
Connection</source>
        <translation>Güvenli olmayan
bağlantı</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="117"/>
        <source>Secured
Connection</source>
        <translation>Güvenli
bağlantı</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>%1 off</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 kapalı</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>off</source>
        <translation>kapalı</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="268"/>
        <source>%1 on</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 açık</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="271"/>
        <source>Connecting to %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 ile bağlantı kuruluyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="274"/>
        <source>Stopping %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 durduruluyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="277"/>
        <source>%1 blocking internet</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 interneti engelliyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="284"/>
        <source>pluggable transport connection</source>
        <translation>değiştirilebilir taşıyıcı bağlantısı</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="286"/>
        <source>connection done</source>
        <translation>bağlantı kuruldu</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="288"/>
        <source>doing handshake</source>
        <translation>el sıkışılıyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="290"/>
        <source>handshake done</source>
        <translation>el sıkışma tamamlandı</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="292"/>
        <source>creating one-hop connection</source>
        <translation>bir duraklı bağlantı oluşturuluyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="294"/>
        <source>requesting status</source>
        <translation>durum isteniyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="296"/>
        <source>loading status</source>
        <translation>durum yükleniyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="298"/>
        <source>loading keys</source>
        <translation>anahtarlar yükleniyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="300"/>
        <source>requesting descriptors</source>
        <translation>belirteçler isteniyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="302"/>
        <source>loading descriptors</source>
        <translation>belirteçler yükleniyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="304"/>
        <source>creating circuit</source>
        <translation>devre kuruluyor</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="306"/>
        <source>done</source>
        <translation>bitti</translation>
    </message>
</context>
<context>
    <name>VPNSwitch</name>
    <message>
        <location filename="../qml/VPNSwitch.qml" line="10"/>
        <source/>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="140"/>
        <source>: a fast and secure VPN. Powered by Bitmask.</source>
        <translation>: hızlı ve güvenilir bir VPN. Bitmask tarafından sunuluyor.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="147"/>
        <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
        <translation>Sistem çubuğu simgesi görüntülenmesin (Gnome kabuk eklentisiyle birlikte ya da VPN bağlantısını başka şekillerde denetlemek için kullanışlıdır)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="154"/>
        <source>Enable Web API.</source>
        <translation>Web API kullanılsın</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="160"/>
        <source>Install helpers (Linux only, requires sudo).</source>
        <translation>Yardımcıları kur (yalnızca Linux üzerinde ve sudo gereklidir)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="166"/>
        <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
        <translation>Trafiği gizlemek için obfs4 kullanılsın. Yalnızca hizmet sağlayıcıda kullanılabiliyorsa</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="172"/>
        <source>Enable autostart.</source>
        <translation>Otomatik başlatma kullanılsın.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="177"/>
        <source>Web API port (default: 8080)</source>
        <translation>Web API bağlantı noktası (varsayılan: 8080)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="180"/>
        <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
        <translation>VPN bağlantısını başlat, &apos;açık&apos; veya &apos;kapalı&apos;.</translation>
    </message>
</context>
</TS>